@@ -3,14 +3,14 @@ BubbleTea - A Python package for building AI chatbots
 With LiteLLM support for easy LLM integration
 """
 
-from .components import Text, Image, Markdown, Card, Cards, Done, Pill, Pills
+from .components import Text, Image, Markdown, Card, Cards, Done, Pill, Pills, Video, Block, Error
 from .decorators import chatbot, config
 from .server import run_server
 from .schemas import ImageInput, BotConfig
 
 __all__ = [
     "Text", "Image", "Markdown", "Card", "Cards", "Done", "Pill", "Pills",
-    "chatbot", "config", "run_server", "ImageInput", "BotConfig", "LLM"
+    "chatbot", "config", "run_server", "ImageInput", "BotConfig", "LLM", "Video", "Block", "Error"
 ]
 
 def __getattr__(name):
